@@ -115,7 +115,19 @@ active_class <- R6::R6Class(
     },
     write_gitignore = function() {
       writeLines(
-        c("*", "!.gitignore", "!meta", "meta/*", "!meta/meta"),
+        c(
+          "# CAUTION: do not edit this file by hand!",
+          "# _targets/objects/ may have large data files,",
+          "# and _targets/meta/process may have sensitive information.",
+          "# It is good pratice to either commit nothing from _targets/,",
+          "# or if your data is not too sensitive,",
+          "# commit only _targets/meta/meta.",
+          "*",
+          "!.gitignore",
+          "!meta",
+          "meta/*",
+          "!meta/meta"
+        ),
         path_gitignore(self$meta$store)
       )
     },
@@ -124,6 +136,7 @@ active_class <- R6::R6Class(
     },
     ensure_process = function() {
       self$process <- process_init(path_store = self$meta$store)
+      self$process$assert_unique()
       self$process$record_process()
       self$process$database$upload(verbose = FALSE)
     },
