@@ -9,25 +9,25 @@ summary_class <- R6::R6Class(
   portable = FALSE,
   cloneable = FALSE,
   public = list(
-    dequeue = function() {
-      if (!is.null(self$queue)) {
-        message(self$queue, appendLF = FALSE)
-        self$queue <- NULL
+    flush_messages = function() {
+      if (!is.null(self$buffer)) {
+        message(self$buffer, appendLF = FALSE)
+        self$buffer <- NULL
       }
     },
     report_start = function() {
       cli_df_header(progress_init(path = tempfile())$cli_data())
     },
     report_progress = function(progress, force = FALSE) {
-      self$queue <- cli_df_body(progress$cli_data(), print = FALSE)
+      self$buffer <- cli_df_body(progress$cli_data(), print = FALSE)
       self$poll()
     },
     report_error = function(error) {
     },
-    report_started = function(target = NULL, progress) {
+    report_dispatched = function(target = NULL, progress, pending = FALSE) {
       self$report_progress(progress)
     },
-    report_built = function(target = NULL, progress) {
+    report_completed = function(target = NULL, progress) {
       self$report_progress(progress)
     },
     report_skipped = function(target = NULL, progress) {
@@ -41,7 +41,7 @@ summary_class <- R6::R6Class(
     },
     report_end = function(progress, seconds_elapsed = NULL) {
       self$report_progress(progress)
-      self$dequeue()
+      self$flush_messages()
       message("")
     }
   )
