@@ -1,8 +1,9 @@
-#' @title List built targets.
+#' @title Deprecated: list built targets.
 #' @export
-#' @family progress
-#' @description List targets whose progress is `"built"`.
-#' @return A character vector of built targets.
+#' @keywords internal
+#' @description Deprecated in favor of [tar_completed()] on 2023-12-04
+#'   (version 1.3.2.9004).
+#' @return A character vector of completed targets.
 #' @inheritParams tar_progress
 #' @param names Optional, names of the targets. If supplied, the
 #'   function restricts its output to these targets.
@@ -18,14 +19,18 @@
 #'   )
 #' }, ask = FALSE)
 #' tar_make()
-#' tar_built()
-#' tar_built(starts_with("y_")) # see also any_of()
+#' tar_completed()
+#' tar_completed(starts_with("y_")) # see also any_of()
 #' })
 #' }
 tar_built <- function(
   names = NULL,
   store = targets::tar_config_get("store")
 ) {
+  tar_warn_deprecate(
+    "tar_built() is deprecated in targets version >= 1.3.2.9004 ",
+    "(2021-12-04). Use tar_completed() instead."
+  )
   tar_assert_allow_meta("tar_built", store)
   progress <- progress_init(path_store = store)
   progress <- tibble::as_tibble(progress$database$read_condensed_data())
@@ -34,5 +39,5 @@ tar_built <- function(
   if (!is.null(names)) {
     progress <- progress[match(names, progress$name), , drop = FALSE] # nolint
   }
-  progress$name[progress$progress == "built"]
+  progress$name[progress$progress == "completed"]
 }
