@@ -41,15 +41,11 @@ file_info_runtime_select <- function(info, x) {
 }
 
 file_move <- function(from, to) {
-  tryCatch(
-    file.rename(from = from, to = to),
+  if (!suppressWarnings(file.rename(from = from, to = to))) {
     # Not feasible to test:
     # nocov start
-    error = function(condition) {
-      file.copy(from = from, to = to, overwrite = TRUE)
-      unlink(from)
-    }
+    file.copy(from = from, to = to, overwrite = TRUE)
     # nocov end
-  )
+  }
   invisible()
 }
