@@ -151,8 +151,8 @@ tar_test("aws_file format invalidation", {
     expr <- tar_tidy_eval(expr, environment(), TRUE)
     eval(as.call(list(`tar_script`, expr, ask = FALSE)))
     tar_make(callr_function = NULL, envir = tar_option_get("envir"))
-    expect_equal(tar_progress(x)$progress, "built")
-    expect_equal(tar_progress(y)$progress, "built")
+    expect_equal(tar_progress(x)$progress, "completed")
+    expect_equal(tar_progress(y)$progress, "completed")
     tar_make(callr_function = NULL)
     progress <- tar_progress()
     progress <- progress[progress$progress != "skipped", ]
@@ -183,8 +183,8 @@ tar_test("aws_file format invalidation", {
     expr <- tar_tidy_eval(expr, environment(), TRUE)
     eval(as.call(list(`tar_script`, expr, ask = FALSE)))
     tar_make(callr_function = NULL, envir = tar_option_get("envir"))
-    expect_equal(tar_progress(x)$progress, "built")
-    expect_equal(tar_progress(y)$progress, "built")
+    expect_equal(tar_progress(x)$progress, "completed")
+    expect_equal(tar_progress(y)$progress, "completed")
     expect_equal(tar_read(y), "x_lines2")
     unlink("example_aws_file.txt")
     aws_s3_delete_bucket(bucket_name)
